==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property postFilterSharpening Post filter sharpening.
 * @property strength Filter strength.
 */
public data class
ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs(
    public val postFilterSharpening: Output<String>? = null,
    public val strength: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs> {
    override fun toJava():
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs.builder()
            .postFilterSharpening(postFilterSharpening?.applyValue({ args0 -> args0 }))
            .strength(strength?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgsBuilder
internal constructor() {
    private var postFilterSharpening: Output<String>? = null

    private var strength: Output<String>? = null

    /**
     * @param value Post filter sharpening.
     */
    @JvmName("vbcofbhatdjmcmbh")
    public suspend fun postFilterSharpening(`value`: Output<String>) {
        this.postFilterSharpening = value
    }

    /**
     * @param value Filter strength.
     */
    @JvmName("myobdtskbinafeag")
    public suspend fun strength(`value`: Output<String>) {
        this.strength = value
    }

    /**
     * @param value Post filter sharpening.
     */
    @JvmName("vnxwgpfghshleayw")
    public suspend fun postFilterSharpening(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.postFilterSharpening = mapped
    }

    /**
     * @param value Filter strength.
     */
    @JvmName("aouokpjdexmsdkgq")
    public suspend fun strength(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.strength = mapped
    }

    internal fun build():
        ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs =
        ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs(
            postFilterSharpening = postFilterSharpening,
            strength = strength,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property postFilterSharpening Post filter sharpening.
 * @property strength Filter strength.
 */
public data class
ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs(
    public val postFilterSharpening: Output<String>? = null,
    public val strength: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs> {
    override fun toJava(): com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs.builder()
            .postFilterSharpening(postFilterSharpening?.applyValue({ args0 -> args0 }))
            .strength(strength?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgsBuilder
internal constructor() {
    private var postFilterSharpening: Output<String>? = null

    private var strength: Output<String>? = null

    /**
     * @param value Post filter sharpening.
     */
    @JvmName("ldttqixpbaxgfxcv")
    public suspend fun postFilterSharpening(`value`: Output<String>) {
        this.postFilterSharpening = value
    }

    /**
     * @param value Filter strength.
     */
    @JvmName("esrtpmdxatvwntyq")
    public suspend fun strength(`value`: Output<String>) {
        this.strength = value
    }

    /**
     * @param value Post filter sharpening.
     */
    @JvmName("uxtnkysckgdgnslu")
    public suspend fun postFilterSharpening(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.postFilterSharpening = mapped
    }

    /**
     * @param value Filter strength.
     */
    @JvmName("ablesrbgyvjmjroc")
    public suspend fun strength(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.strength = mapped
    }

    internal fun build(): ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs =
        ChannelEncoderSettingsVideoDescriptionCodecSettingsH265SettingsFilterSettingsTemporalFilterSettingsArgs(
            postFilterSharpening = postFilterSharpening,
            strength = strength,
        )
}
